@@ -14,6 +14,11 @@
 
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
@@ -457,7 +462,7 @@ class LoaderScript(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 		if value is not None:
 			assert type(value) is dict, "'{0}' attribute: '{1}' type is not 'dict'!".format("overrideKeys", value)
 			for key, element in value.iteritems():
-				assert type(key) in (str, unicode), "'{0}' attribute: '{1}' type is not 'str' or 'unicode'!".format(
+				assert type(key) is unicode, "'{0}' attribute: '{1}' type is not 'unicode'!".format(
 				"overrideKeys", key)
 				assert type(element) is foundations.parsers.AttributeCompound, \
 				"'{0}' attribute: '{1}' type is not 'foundations.parsers.AttributeCompound'!".format(
@@ -494,7 +499,7 @@ class LoaderScript(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 		"""
 
 		if value is not None:
-			assert type(value) in (str, unicode), "'{0}' attribute: '{1}' type is not 'str' or 'unicode'!".format(
+			assert type(value) is unicode, "'{0}' attribute: '{1}' type is not 'unicode'!".format(
 			"defaultStringSeparator", value)
 			assert len(value) == 1, "'{0}' attribute: '{1}' has multiples characters!".format(
 			"defaultStringSeparator", value)
@@ -532,7 +537,7 @@ class LoaderScript(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 		"""
 
 		if value is not None:
-			assert type(value) in (str, unicode), "'{0}' attribute: '{1}' type is not 'str' or 'unicode'!".format(
+			assert type(value) is unicode, "'{0}' attribute: '{1}' type is not 'unicode'!".format(
 			"unnamedLightName", value)
 		self.__unnamedLightName = value
 
@@ -851,7 +856,7 @@ class LoaderScript(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 			try:
 				connection = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 				connection.settimeout(2.5)
-				connection.connect((foundations.strings.encode(self.__tcpClientUi.address), 	self.__tcpClientUi.port))
+				connection.connect((foundations.strings.toString(self.__tcpClientUi.address), 	self.__tcpClientUi.port))
 				socketCommand = foundations.parsers.getAttributeCompound("ExecutionCommand",
 								templateSectionsFileParser.getValue("ExecutionCommand",
 								self.__templateRemoteConnectionSection)).value.replace("$loaderScriptPath",
@@ -942,7 +947,7 @@ class LoaderScript(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 		This method builds a Loader Script.
 
 		:param template: Template path. ( String )
-		:param iblSet: iblSet path. ( String )
+		:param iblSet: Ibl Set path. ( String )
 		:param overrideKeys: Override keys. ( Dictionary )
 		:return: Loader Script. ( List )
 		"""
@@ -1011,10 +1016,11 @@ class LoaderScript(QWidgetComponentFactory(uiFile=COMPONENT_FILE)):
 			if bindingParameters:
 				for parameter in bindingParameters:
 					for attribute in bindedAttributes.itervalues():
-						if parameter == attribute.link:
-							LOGGER.debug(
-							"> Updating Loader Script parameter '{0}' with value: '{1}'.".format(parameter,
-																								attribute.value))
-							line = line.replace(parameter, attribute.value and attribute.value or "-1")
+						if not parameter == attribute.link:
+							continue
+
+						LOGGER.debug("> Updating Loader Script parameter '{0}' with value: '{1}'.".format(parameter,
+																										attribute.value))
+						line = line.replace(parameter, attribute.value if attribute.value else "-1")
 			boundLoaderScript.append(line)
 		return boundLoaderScript
