@@ -14,6 +14,11 @@
 
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
@@ -526,7 +531,7 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 		:note: This method may require user interaction.
 		"""
 
-		return self.setTagsCloudMatchingIblsSets(foundations.strings.encode(self.Search_Database_lineEdit.text()),
+		return self.setTagsCloudMatchingIblsSets(foundations.strings.toString(self.Search_Database_lineEdit.text()),
 		not self.Case_Sensitive_Matching_pushButton.isChecked() and re.IGNORECASE or 0)
 
 	def setTimeMatchingIblSetsUi(self):
@@ -591,7 +596,7 @@ class SearchDatabase(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 			filteredIblSets = [iblSet for iblSet in set(iblSets).intersection(set(filteredIblSets))]
 
 			LOGGER.debug("> Tags Cloud filtered Ibl Set(s): '{0}'".format(
-			", ".join((foundations.strings.encode(iblSet.name) for iblSet in filteredIblSets))))
+			", ".join((foundations.strings.toString(iblSet.name) for iblSet in filteredIblSets))))
 
 			self.__iblSetsOutliner.setIblSets(filteredIblSets)
 		return True
