@@ -14,6 +14,11 @@
 
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
@@ -24,7 +29,6 @@ if sys.version_info[:2] <= (2, 6):
 	from ordereddict import OrderedDict
 else:
 	from collections import OrderedDict
-from PyQt4.QtCore import QVariant
 from PyQt4.QtCore import Qt
 from PyQt4.QtCore import pyqtSignal
 from PyQt4.QtGui import QFileDialog
@@ -52,7 +56,6 @@ from sibl_gui.components.core.collectionsOutliner.models import CollectionsModel
 from sibl_gui.components.core.collectionsOutliner.nodes import OverallCollectionNode
 from sibl_gui.components.core.collectionsOutliner.views import IblSetsCollections_QTreeView
 from sibl_gui.components.core.database.nodes import CollectionNode
-from sibl_gui.components.core.database.types import IblSet
 from umbra.globals.runtimeGlobals import RuntimeGlobals
 
 #**********************************************************************************************************************
@@ -721,7 +724,7 @@ class CollectionsOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 			LOGGER.info("{0} | Database default Collection wizard deactivated by '{1}' command line parameter value!".format(
 			self.__class__.__name__, "databaseReadOnly"))
 
-		activeCollectionsIdentities = foundations.strings.encode(
+		activeCollectionsIdentities = foundations.strings.toString(
 		self.__settings.getKey(self.__settingsSection, "activeCollections").toString())
 		LOGGER.debug("> '{0}' View stored selected Collections identities '{1}'.".format(self.__class__.__name__,
 																						activeCollectionsIdentities))
@@ -729,7 +732,7 @@ class CollectionsOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 													[int(identity) for identity in activeCollectionsIdentities.split(
 													self.__settingsSeparator)] or []
 
-		activeOverallCollection = foundations.strings.encode(
+		activeOverallCollection = foundations.strings.toString(
 		self.__settings.getKey(self.__settingsSection, "activeOverallCollection").toString())
 		LOGGER.debug("> '{0}' View stored 'Overall' Collection: '{1}'.".format(self.__class__.__name__,
 																				activeOverallCollection))
@@ -750,12 +753,12 @@ class CollectionsOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 		self.__view.storeModelSelection()
 		self.__settings.setKey(self.__settingsSection,
 								"activeCollections",
-								self.__settingsSeparator.join((foundations.strings.encode(
+								self.__settingsSeparator.join((foundations.strings.toString(
 								identity) for identity in self.__view.modelSelection[
 								"Collections"])))
 		self.__settings.setKey(self.__settingsSection,
 								"activeOverallCollection",
-								self.__settingsSeparator.join((foundations.strings.encode(name)
+								self.__settingsSeparator.join((foundations.strings.toString(name)
 								for name in self.__view.modelSelection[self.__overallCollection])))
 		return True
 
@@ -920,7 +923,7 @@ class CollectionsOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 			return False
 
 		if collectionInformations:
-			collectionInformations = foundations.strings.encode(collectionInformations).split(",")
+			collectionInformations = foundations.strings.toString(collectionInformations).split(",")
 			name = collectionInformations[0].strip()
 			if name != self.__overallCollection:
 				if not self.collectionExists(name):
@@ -972,7 +975,7 @@ class CollectionsOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 			return False
 
 		if messageBox.messageBox("Question", "Question",
-		"Are you sure you want to remove '{0}' Collection(s)?".format(", ".join((foundations.strings.encode(collection.name)
+		"Are you sure you want to remove '{0}' Collection(s)?".format(", ".join((foundations.strings.toString(collection.name)
 																	for collection in selectedCollections))),
 		buttons=QMessageBox.Yes | QMessageBox.No) == QMessageBox.Yes:
 			self.__engine.startProcessing("Removing Collections ...", len(selectedCollections))
@@ -1032,7 +1035,7 @@ class CollectionsOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 			iblSet.collection = self.getCollectionId(self.__defaultCollection)
 
 		LOGGER.info("{0} | Removing '{1}' Collection from the Database!".format(self.__class__.__name__, collection.name))
-		if sibl_gui.components.core.database.operations.removeCollection(foundations.strings.encode(collection.id)):
+		if sibl_gui.components.core.database.operations.removeCollection(foundations.strings.toString(collection.id)):
 			self.refreshNodes.emit()
 			self.__iblSetsOutliner.refreshNodes.emit()
 			return True
@@ -1066,7 +1069,7 @@ class CollectionsOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 			return list()
 
 		return sibl_gui.components.core.database.operations.filterIblSetsCollections(
-		"{0}".format(foundations.strings.encode(pattern.pattern)), attribute, flags)
+		"{0}".format(foundations.strings.toString(pattern.pattern)), attribute, flags)
 
 	def collectionExists(self, name):
 		"""
@@ -1118,7 +1121,7 @@ class CollectionsOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 												parent=overallCollectionNode,
 												nodeFlags=nodeFlags,
 												attributesFlags=attributesFlags)
-			collectionNode.roles[Qt.DecorationRole] = decorationRole
+			collectionNode.roles[Qt.DecorationRole] = foundations.common.filterPath(decorationRole)
 		overallCollectionNode.updateNodeAttributes()
 		rootNode.sortChildren()
 
