@@ -14,6 +14,11 @@
 
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
@@ -22,12 +27,13 @@ from PyQt4.QtCore import Qt
 #**********************************************************************************************************************
 #***	Internal imports.
 #**********************************************************************************************************************
+import foundations.common
 import foundations.exceptions
 import foundations.strings
 import foundations.verbose
-import umbra.ui.nodes
 import sibl_gui.components.core.database.operations
 import sibl_gui.ui.common
+import sibl_gui.ui.nodes
 from umbra.globals.constants import Constants
 
 #**********************************************************************************************************************
@@ -63,7 +69,7 @@ def getTemplateUserName(title, software):
 
 	return foundations.strings.removeStrip(title, software)
 
-class AbstractDatabaseNode(umbra.ui.nodes.GraphModelNode):
+class AbstractDatabaseNode(sibl_gui.ui.nodes.GraphModelNode):
 	"""
 	This class defines Application Database abstract base class used by concrete Database Node classes.
 	"""
@@ -79,6 +85,8 @@ class AbstractDatabaseNode(umbra.ui.nodes.GraphModelNode):
 				roles=None,
 				nodeFlags=None,
 				attributesFlags=int(Qt.ItemIsSelectable | Qt.ItemIsEditable | Qt.ItemIsEnabled | Qt.ItemIsDragEnabled),
+				iconSize=None,
+				iconPlaceholder=None,
 				**kwargs):
 		"""
 		This method initializes the class.
@@ -90,16 +98,26 @@ class AbstractDatabaseNode(umbra.ui.nodes.GraphModelNode):
 		:param roles: Roles. ( Dictionary )
 		:param nodeFlags: Node flags. ( Integer )
 		:param attributesFlags: Attributes flags. ( Integer )
+		:param iconSize: Icon size.  ( String )
+		:param iconPlaceholder: Icon placeholder.  ( QIcon )
 		:param \*\*kwargs: Keywords arguments. ( \*\* )
 		"""
 
 		LOGGER.debug("> Initializing '{0}()' class.".format(self.__class__.__name__))
 
-		umbra.ui.nodes.GraphModelNode.__init__(self, name, parent, children, roles, nodeFlags, **kwargs)
+		sibl_gui.ui.nodes.GraphModelNode.__init__(self,
+												name,
+												parent,
+												children,
+												roles,
+												nodeFlags,
+												iconSize,
+												iconPlaceholder,
+												**kwargs)
 
 		# --- Setting class attributes. ---
 		self.__databaseItem = databaseItem
-		self.__toolTipText = unicode()
+		self.__toolTipText = ""
 
 		AbstractDatabaseNode.__initializeNode(self, attributesFlags)
 
@@ -158,7 +176,7 @@ class AbstractDatabaseNode(umbra.ui.nodes.GraphModelNode):
 		"""
 
 		if value is not None:
-			assert type(value) in (str, unicode), "'{0}' attribute: '{1}' type is not 'str' or 'unicode'!".format(
+			assert type(value) is unicode, "'{0}' attribute: '{1}' type is not 'unicode'!".format(
 			"toolTipText", value)
 		self.__toolTipText = value
 
@@ -190,7 +208,7 @@ class AbstractDatabaseNode(umbra.ui.nodes.GraphModelNode):
 			value = getattr(self.__databaseItem, attribute)
 			roles = {Qt.DisplayRole : value,
 					Qt.EditRole : value}
-			self[attribute] = umbra.ui.nodes.GraphModelAttribute(attribute, value, roles, attributesFlags)
+			self[attribute] = sibl_gui.ui.nodes.GraphModelAttribute(attribute, value, roles, attributesFlags)
 
 	def updateNode(self):
 		"""
@@ -214,7 +232,7 @@ class AbstractDatabaseNode(umbra.ui.nodes.GraphModelNode):
 			if not attribute in self:
 				continue
 
-			if issubclass(self[attribute].__class__, umbra.ui.nodes.GraphModelAttribute):
+			if issubclass(self[attribute].__class__, sibl_gui.ui.nodes.GraphModelAttribute):
 				self[attribute].value = self[attribute].roles[Qt.DisplayRole] = self[attribute].roles[Qt.EditRole] = \
 				getattr(self.__databaseItem, attribute)
 		return True
@@ -241,7 +259,7 @@ class AbstractDatabaseNode(umbra.ui.nodes.GraphModelNode):
 			if not attribute in self:
 				continue
 
-			if issubclass(self[attribute].__class__, umbra.ui.nodes.GraphModelAttribute):
+			if issubclass(self[attribute].__class__, sibl_gui.ui.nodes.GraphModelAttribute):
 				setattr(self.__databaseItem, attribute, self[attribute].value)
 		return True
 
@@ -272,6 +290,9 @@ class IblSetNode(AbstractDatabaseNode):
 				roles=None,
 				nodeFlags=None,
 				attributesFlags=None,
+				iconPath=None,
+				iconSize=None,
+				iconPlaceholder=None,
 				**kwargs):
 		"""
 		This method initializes the class.
@@ -283,14 +304,28 @@ class IblSetNode(AbstractDatabaseNode):
 		:param roles: Roles. ( Dictionary )
 		:param nodeFlags: Node flags. ( Integer )
 		:param attributesFlags: Attributes flags. ( Integer )
+		:param iconPath: Icon path.  ( String )
+		:param iconSize: Icon size.  ( String )
+		:param iconPlaceholder: Icon placeholder.  ( QIcon )
 		:param \*\*kwargs: Keywords arguments. ( \*\* )
 		"""
 
 		LOGGER.debug("> Initializing '{0}()' class.".format(self.__class__.__name__))
 
-		AbstractDatabaseNode.__init__(self, databaseItem, name, parent, children, roles, nodeFlags, attributesFlags, **kwargs)
+		AbstractDatabaseNode.__init__(self,
+									databaseItem,
+									name,
+									parent,
+									children,
+									roles,
+									nodeFlags,
+									attributesFlags,
+									iconSize,
+									iconPlaceholder,
+									**kwargs)
 
 		# --- Setting class attributes. ---
+		self.__iconPath = iconPath
 		self.toolTipText = """
 				<p><b>{0}</b></p>
 				<p><b>Author: </b>{1}<br>
@@ -301,6 +336,41 @@ class IblSetNode(AbstractDatabaseNode):
 
 		IblSetNode.__initializeNode(self)
 
+	#******************************************************************************************************************
+	#***	Attributes properties.
+	#******************************************************************************************************************
+	@property
+	def iconPath(self):
+		"""
+		This method is the property for **self.__iconPath** attribute.
+
+		:return: self.__iconPath. ( String )
+		"""
+
+		return self.__iconPath
+
+	@iconPath.setter
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
+	def iconPath(self, value):
+		"""
+		This method is the setter method for **self.__iconPath** attribute.
+
+		:param value: Attribute value. ( String )
+		"""
+
+		raise foundations.exceptions.ProgrammingError(
+		"{0} | '{1}' attribute is read only!".format(self.__class__.__name__, "iconPath"))
+
+	@iconPath.deleter
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
+	def iconPath(self):
+		"""
+		This method is the deleter method for **self.__iconPath** attribute.
+		"""
+
+		raise foundations.exceptions.ProgrammingError(
+		"{0} | '{1}' attribute is not deletable!".format(self.__class__.__name__, "iconPath"))
+
 	#******************************************************************************************************************
 	#***	Class methods.
 	#******************************************************************************************************************
@@ -310,7 +380,7 @@ class IblSetNode(AbstractDatabaseNode):
 		"""
 
 		self.roles.update({Qt.DisplayRole : self.databaseItem.title,
-							Qt.DecorationRole : self.databaseItem.icon,
+							Qt.DecorationRole : foundations.common.filterPath(self.__iconPath),
 							Qt.EditRole : self.databaseItem.title})
 		self.updateToolTip()
 
@@ -374,6 +444,8 @@ class TemplateNode(AbstractDatabaseNode):
 				roles=None,
 				nodeFlags=None,
 				attributesFlags=None,
+				iconSize=None,
+				iconPlaceholder=None,
 				**kwargs):
 		"""
 		This method initializes the class.
@@ -385,12 +457,24 @@ class TemplateNode(AbstractDatabaseNode):
 		:param roles: Roles. ( Dictionary )
 		:param nodeFlags: Node flags. ( Integer )
 		:param attributesFlags: Attributes flags. ( Integer )
+		:param iconSize: Icon size.  ( String )
+		:param iconPlaceholder: Icon placeholder.  ( QIcon )
 		:param \*\*kwargs: Keywords arguments. ( \*\* )
 		"""
 
 		LOGGER.debug("> Initializing '{0}()' class.".format(self.__class__.__name__))
 
-		AbstractDatabaseNode.__init__(self, databaseItem, name, parent, children, roles, nodeFlags, attributesFlags, **kwargs)
+		AbstractDatabaseNode.__init__(self,
+									databaseItem,
+									name,
+									parent,
+									children,
+									roles,
+									nodeFlags,
+									attributesFlags,
+									iconSize,
+									iconPlaceholder,
+									**kwargs)
 
 		# --- Setting class attributes. ---
 		self.toolTipText = """
@@ -476,6 +560,8 @@ class CollectionNode(AbstractDatabaseNode):
 				roles=None,
 				nodeFlags=None,
 				attributesFlags=None,
+				iconSize=None,
+				iconPlaceholder=None,
 				**kwargs):
 		"""
 		This method initializes the class.
@@ -487,12 +573,24 @@ class CollectionNode(AbstractDatabaseNode):
 		:param roles: Roles. ( Dictionary )
 		:param nodeFlags: Node flags. ( Integer )
 		:param attributesFlags: Attributes flags. ( Integer )
+		:param iconSize: Icon size.  ( String )
+		:param iconPlaceholder: Icon placeholder.  ( QIcon )
 		:param \*\*kwargs: Keywords arguments. ( \*\* )
 		"""
 
 		LOGGER.debug("> Initializing '{0}()' class.".format(self.__class__.__name__))
 
-		AbstractDatabaseNode.__init__(self, databaseItem, name, parent, children, roles, nodeFlags, attributesFlags, **kwargs)
+		AbstractDatabaseNode.__init__(self,
+									databaseItem,
+									name,
+									parent,
+									children,
+									roles,
+									nodeFlags,
+									attributesFlags,
+									iconSize,
+									iconPlaceholder,
+									**kwargs)
 
 		# --- Setting class attributes. ---
 		self.toolTipText = """
@@ -510,7 +608,7 @@ class CollectionNode(AbstractDatabaseNode):
 		This method initializes the node.
 		"""
 
-		self["count"] = umbra.ui.nodes.GraphModelAttribute(
+		self["count"] = sibl_gui.ui.nodes.GraphModelAttribute(
 						name="count",
 						value=sibl_gui.components.core.database.operations.getCollectionIblSetsCount(self.databaseItem),
 						flags=int(Qt.ItemIsSelectable | Qt.ItemIsEnabled))
