@@ -14,6 +14,11 @@
 
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
@@ -49,6 +54,7 @@ import foundations.verbose
 import foundations.walkers
 import sibl_gui.components.core.database.exceptions
 import sibl_gui.components.core.database.operations
+import sibl_gui.ui.common
 import umbra.engine
 import umbra.exceptions
 import umbra.ui.common
@@ -57,11 +63,10 @@ import umbra.ui.widgets.messageBox as messageBox
 from manager.qwidgetComponent import QWidgetComponentFactory
 from sibl_gui.components.core.database.nodes import IblSetNode
 from sibl_gui.components.core.iblSetsOutliner.models import IblSetsModel
-from sibl_gui.components.core.iblSetsOutliner.views import Columns_QListView
 from sibl_gui.components.core.iblSetsOutliner.views import Details_QTreeView
 from sibl_gui.components.core.iblSetsOutliner.views import Thumbnails_QListView
-from umbra.globals.runtimeGlobals import RuntimeGlobals
 from umbra.globals.uiConstants import UiConstants
+from umbra.globals.runtimeGlobals import RuntimeGlobals
 from umbra.ui.widgets.search_QLineEdit import Search_QLineEdit
 
 #**********************************************************************************************************************
@@ -126,6 +131,9 @@ class IblSetsOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 		self.__uiDetailsViewImage = "Details_View.png"
 		self.__uiLargestSizeImage = "Largest_Size.png"
 		self.__uiSmallestSizeImage = "Smallest_Size.png"
+		self.__uiPanoramicLoadingImage = "Panoramic_Loading.png"
+		self.__uiSquareLoadingImage = "Square_Loading.png"
+		self.__uiSwitchThumbnailsTypeImage = "Switch_Thumbnails_Type.png"
 		self.__dockArea = 8
 
 		self.__engine = None
@@ -144,7 +152,6 @@ class IblSetsOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 		self.__views = None
 		self.__viewsPushButtons = None
 		self.__thumbnailsView = None
-		self.__columnsView = None
 		self.__detailsView = None
 		self.__detailsHeaders = OrderedDict([("Ibl Set", "title"),
 										("Author", "author"),
@@ -155,6 +162,11 @@ class IblSetsOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 										("Shot Time", "time"),
 										("Comment", "comment")])
 
+		self.__panoramicThumbnails = "True"
+		self.__panoramicThumbnailsSize = "XLarge"
+		self.__squareThumbnailsSize = "Medium"
+		self.__thumbnailsMinimumSize = "XSmall"
+
 		self.__searchContexts = OrderedDict([("Search In Names", "title"),
 								("Search In Authors", "author"),
 								("Search In Links", "link"),
@@ -163,6 +175,8 @@ class IblSetsOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 		self.__activeSearchContext = "Search In Names"
 		self.__searchContextsMenu = None
 
+		self.__iconPlaceHolder = None
+
 	#******************************************************************************************************************
 	#***	Attributes properties.
 	#******************************************************************************************************************
@@ -358,6 +372,101 @@ class IblSetsOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 		raise foundations.exceptions.ProgrammingError(
 		"{0} | '{1}' attribute is not deletable!".format(self.__class__.__name__, "uiSmallestSizeImage"))
 
+	@property
+	def uiPanoramicLoadingImage(self):
+		"""
+		This method is the property for **self.__uiPanoramicLoadingImage** attribute.
+
+		:return: self.__uiPanoramicLoadingImage. ( String )
+		"""
+
+		return self.__uiPanoramicLoadingImage
+
+	@uiPanoramicLoadingImage.setter
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
+	def uiPanoramicLoadingImage(self, value):
+		"""
+		This method is the setter method for **self.__uiPanoramicLoadingImage** attribute.
+
+		:param value: Attribute value. ( String )
+		"""
+
+		raise foundations.exceptions.ProgrammingError(
+		"{0} | '{1}' attribute is read only!".format(self.__class__.__name__, "uiPanoramicLoadingImage"))
+
+	@uiPanoramicLoadingImage.deleter
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
+	def uiPanoramicLoadingImage(self):
+		"""
+		This method is the deleter method for **self.__uiPanoramicLoadingImage** attribute.
+		"""
+
+		raise foundations.exceptions.ProgrammingError(
+		"{0} | '{1}' attribute is not deletable!".format(self.__class__.__name__, "uiPanoramicLoadingImage"))
+
+	@property
+	def uiSquareLoadingImage(self):
+		"""
+		This method is the property for **self.__uiSquareLoadingImage** attribute.
+
+		:return: self.__uiSquareLoadingImage. ( String )
+		"""
+
+		return self.__uiSquareLoadingImage
+
+	@uiSquareLoadingImage.setter
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
+	def uiSquareLoadingImage(self, value):
+		"""
+		This method is the setter method for **self.__uiSquareLoadingImage** attribute.
+
+		:param value: Attribute value. ( String )
+		"""
+
+		raise foundations.exceptions.ProgrammingError(
+		"{0} | '{1}' attribute is read only!".format(self.__class__.__name__, "uiSquareLoadingImage"))
+
+	@uiSquareLoadingImage.deleter
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
+	def uiSquareLoadingImage(self):
+		"""
+		This method is the deleter method for **self.__uiSquareLoadingImage** attribute.
+		"""
+
+		raise foundations.exceptions.ProgrammingError(
+		"{0} | '{1}' attribute is not deletable!".format(self.__class__.__name__, "uiSquareLoadingImage"))
+	@property
+	def uiSwitchThumbnailsTypeImage(self):
+		"""
+		This method is the property for **self.__uiSwitchThumbnailsTypeImage** attribute.
+
+		:return: self.__uiSwitchThumbnailsTypeImage. ( String )
+		"""
+
+		return self.__uiSwitchThumbnailsTypeImage
+
+	@uiSwitchThumbnailsTypeImage.setter
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
+	def uiSwitchThumbnailsTypeImage(self, value):
+		"""
+		This method is the setter method for **self.__uiSwitchThumbnailsTypeImage** attribute.
+
+		:param value: Attribute value. ( String )
+		"""
+
+		raise foundations.exceptions.ProgrammingError(
+		"{0} | '{1}' attribute is read only!".format(self.__class__.__name__, "uiSwitchThumbnailsTypeImage"))
+
+	@uiSwitchThumbnailsTypeImage.deleter
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
+	def uiSwitchThumbnailsTypeImage(self):
+		"""
+		This method is the deleter method for **self.__uiSwitchThumbnailsTypeImage** attribute.
+		"""
+
+		raise foundations.exceptions.ProgrammingError(
+		"{0} | '{1}' attribute is not deletable!".format(self.__class__.__name__, "uiSwitchThumbnailsTypeImage"))
+
 	@property
 	def dockArea(self):
 		"""
@@ -774,38 +883,6 @@ class IblSetsOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 		raise foundations.exceptions.ProgrammingError(
 		"{0} | '{1}' attribute is not deletable!".format(self.__class__.__name__, "view"))
 
-	@property
-	def columnsView(self):
-		"""
-		This method is the property for **self.__columnsView** attribute.
-
-		:return: self.__columnsView. ( QListView )
-		"""
-
-		return self.__columnsView
-
-	@columnsView.setter
-	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
-	def columnsView(self, value):
-		"""
-		This method is the setter method for **self.__columnsView** attribute.
-
-		:param value: Attribute value. ( QListView )
-		"""
-
-		raise foundations.exceptions.ProgrammingError(
-		"{0} | '{1}' attribute is read only!".format(self.__class__.__name__, "columnsView"))
-
-	@columnsView.deleter
-	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
-	def columnsView(self):
-		"""
-		This method is the deleter method for **self.__columnsView** attribute.
-		"""
-
-		raise foundations.exceptions.ProgrammingError(
-		"{0} | '{1}' attribute is not deletable!".format(self.__class__.__name__, "view"))
-
 	@property
 	def detailsView(self):
 		"""
@@ -870,6 +947,138 @@ class IblSetsOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 		raise foundations.exceptions.ProgrammingError(
 		"{0} | '{1}' attribute is not deletable!".format(self.__class__.__name__, "view"))
 
+	@property
+	def panoramicThumbnails(self):
+		"""
+		This method is the property for **self.__panoramicThumbnails** attribute.
+
+		:return: self.__panoramicThumbnails. ( Boolean )
+		"""
+
+		return self.__panoramicThumbnails
+
+	@panoramicThumbnails.setter
+	@foundations.exceptions.handleExceptions(AssertionError)
+	def panoramicThumbnails(self, value):
+		"""
+		This method is the setter method for **self.__panoramicThumbnails** attribute.
+
+		:param value: Attribute value. ( Boolean )
+		"""
+
+		if value is not None:
+			assert type(value) is bool, "'{0}' attribute: '{1}' type is not 'bool'!".format("panoramicThumbnails", value)
+		self.setPanoramicThumbnails(value)
+
+	@panoramicThumbnails.deleter
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
+	def panoramicThumbnails(self):
+		"""
+		This method is the deleter method for **self.__panoramicThumbnails** attribute.
+		"""
+
+		raise foundations.exceptions.ProgrammingError(
+		"{0} | '{1}' attribute is not deletable!".format(self.__class__.__name__, "panoramicThumbnails"))
+
+	@property
+	def panoramicThumbnailsSize(self):
+		"""
+		This method is the property for **self.__panoramicThumbnailsSize** attribute.
+
+		:return: self.__panoramicThumbnailsSize. ( String )
+		"""
+
+		return self.__panoramicThumbnailsSize
+
+	@panoramicThumbnailsSize.setter
+	@foundations.exceptions.handleExceptions(AssertionError)
+	def panoramicThumbnailsSize(self, value):
+		"""
+		This method is the setter method for **self.__panoramicThumbnailsSize** attribute.
+
+		:param value: Attribute value. ( String )
+		"""
+
+		if value is not None:
+			assert type(value) is unicode, "'{0}' attribute: '{1}' type is not 'unicode'!".format("panoramicThumbnailsSize", value)
+		self.__panoramicThumbnailsSize = value
+
+	@panoramicThumbnailsSize.deleter
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
+	def panoramicThumbnailsSize(self):
+		"""
+		This method is the deleter method for **self.__panoramicThumbnailsSize** attribute.
+		"""
+
+		raise foundations.exceptions.ProgrammingError(
+		"{0} | '{1}' attribute is not deletable!".format(self.__class__.__name__, "panoramicThumbnailsSize"))
+
+	@property
+	def squareThumbnailsSize(self):
+		"""
+		This method is the property for **self.__squareThumbnailsSize** attribute.
+
+		:return: self.__squareThumbnailsSize. ( String )
+		"""
+
+		return self.__squareThumbnailsSize
+
+	@squareThumbnailsSize.setter
+	@foundations.exceptions.handleExceptions(AssertionError)
+	def squareThumbnailsSize(self, value):
+		"""
+		This method is the setter method for **self.__squareThumbnailsSize** attribute.
+
+		:param value: Attribute value. ( String )
+		"""
+
+		if value is not None:
+			assert type(value) is unicode, "'{0}' attribute: '{1}' type is not 'unicode'!".format("squareThumbnailsSize", value)
+		self.__squareThumbnailsSize = value
+
+	@squareThumbnailsSize.deleter
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
+	def squareThumbnailsSize(self):
+		"""
+		This method is the deleter method for **self.__squareThumbnailsSize** attribute.
+		"""
+
+		raise foundations.exceptions.ProgrammingError(
+		"{0} | '{1}' attribute is not deletable!".format(self.__class__.__name__, "squareThumbnailsSize"))
+
+	@property
+	def thumbnailsMinimumSize(self):
+		"""
+		This method is the property for **self.__thumbnailsMinimumSize** attribute.
+
+		:return: self.__thumbnailsMinimumSize. ( Dictionary )
+		"""
+
+		return self.__thumbnailsMinimumSize
+
+	@thumbnailsMinimumSize.setter
+	@foundations.exceptions.handleExceptions(AssertionError)
+	def thumbnailsMinimumSize(self, value):
+		"""
+		This method is the setter method for **self.__thumbnailsMinimumSize** attribute.
+
+		:param value: Attribute value. ( Dictionary )
+		"""
+
+		if value is not None:
+			assert type(value) is unicode, "'{0}' attribute: '{1}' type is not 'unicode'!".format("thumbnailsMinimumSize", value)
+		self.__thumbnailsMinimumSize = value
+
+	@thumbnailsMinimumSize.deleter
+	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
+	def thumbnailsMinimumSize(self):
+		"""
+		This method is the deleter method for **self.__thumbnailsMinimumSize** attribute.
+		"""
+
+		raise foundations.exceptions.ProgrammingError(
+		"{0} | '{1}' attribute is not deletable!".format(self.__class__.__name__, "thumbnailsMinimumSize"))
+
 	@property
 	def searchContexts(self):
 		"""
@@ -1022,19 +1231,8 @@ class IblSetsOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 													"No Ibl Set to view!")
 		self.__thumbnailsView.setObjectName("Thumbnails_listView")
 		self.__thumbnailsView.setContextMenuPolicy(Qt.ActionsContextMenu)
-		listViewIconSize, state = self.__settings.getKey(self.__settingsSection, "listViewIconSize").toInt()
-		if state:
-			self.__thumbnailsView.listViewIconSize = listViewIconSize
 		self.Ibl_Sets_Outliner_stackedWidget.addWidget(self.__thumbnailsView)
 
-		self.__columnsView = Columns_QListView(self,
-											self.__model,
-											self.__engine.parameters.databaseReadOnly,
-											"No Ibl Set to view!")
-		self.__columnsView.setObjectName("Columns_listView")
-		self.__columnsView.setContextMenuPolicy(Qt.ActionsContextMenu)
-		self.Ibl_Sets_Outliner_stackedWidget.addWidget(self.__columnsView)
-
 		self.__detailsView = Details_QTreeView(self,
 											self.__model,
 											self.__engine.parameters.databaseReadOnly,
@@ -1043,16 +1241,17 @@ class IblSetsOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 		self.__detailsView.setContextMenuPolicy(Qt.ActionsContextMenu)
 		self.Ibl_Sets_Outliner_stackedWidget.addWidget(self.__detailsView)
 
-		self.__views = (self.__thumbnailsView, self.__columnsView, self.__detailsView)
+		self.__views = (self.__thumbnailsView, self.__detailsView)
 		self.__views_addActions()
 		self.__viewsPushButtons = {0 : (self.Thumbnails_View_pushButton, self.__uiThumbnailsViewImage),
-									1 : (self.Columns_View_pushButton, self.__uiColumnsViewImage),
-									2 : (self.Details_View_pushButton, self.__uiDetailsViewImage)}
+									1 : (self.Details_View_pushButton, self.__uiDetailsViewImage)}
 
 		for index, data in self.__viewsPushButtons.iteritems():
 			viewPushButton, image = data
 			viewPushButton.setIcon(QIcon(os.path.join(self.__uiResourcesDirectory, image)))
 
+		self.Switch_Thumbnails_Type_pushButton.setIcon(QIcon(os.path.join(self.__uiResourcesDirectory, self.__uiSwitchThumbnailsTypeImage)))
+
 		self.Search_Database_lineEdit = Search_QLineEdit(self)
 		self.Search_Database_horizontalLayout.addWidget(self.Search_Database_lineEdit)
 		self.Search_Database_lineEdit.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
@@ -1066,10 +1265,15 @@ class IblSetsOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 		self.Search_Database_lineEdit.searchActiveLabel.setMenu(self.__searchContextsMenu)
 		self.setActiveSearchContext(self.__activeSearchContext)
 
-		self.Thumbnails_Size_horizontalSlider.setValue(self.__thumbnailsView.listViewIconSize)
 		self.Largest_Size_label.setPixmap(QPixmap(os.path.join(self.__uiResourcesDirectory, self.__uiLargestSizeImage)))
 		self.Smallest_Size_label.setPixmap(QPixmap(os.path.join(self.__uiResourcesDirectory, self.__uiSmallestSizeImage)))
 
+		if self.__settings.keyExists(self.__settingsSection, "panoramicThumbnails"):
+			self.__panoramicThumbnails = self.__settings.getKey(self.__settingsSection, "panoramicThumbnails").toBool()
+
+		self.__views_setUi(
+		foundations.common.getFirstItem(self.__settings.getKey(self.__settingsSection, "listViewIconSize").toInt()))
+
 		# Signals / Slots.
 		for view in self.__views:
 			self.__engine.imagesCaches.QIcon.contentAdded.connect(view.viewport().update)
@@ -1079,6 +1283,7 @@ class IblSetsOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 			viewPushButton, image = data
 			viewPushButton.clicked.connect(functools.partial(self.__views_pushButtons__clicked, index))
 
+		self.Switch_Thumbnails_Type_pushButton.clicked.connect(self.__Switch_Thumbnails_Type_pushButton__clicked)
 		self.Search_Database_lineEdit.textChanged.connect(self.__Search_Database_lineEdit__textChanged)
 
 		self.Thumbnails_Size_horizontalSlider.valueChanged.connect(self.__Thumbnails_Size_horizontalSlider__changed)
@@ -1184,7 +1389,7 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 
 		for view in self.__views:
 			viewName = view.objectName()
-			viewSelectedIblSetsIdentities = foundations.strings.encode(self.__settings.getKey(self.__settingsSection,
+			viewSelectedIblSetsIdentities = foundations.strings.toString(self.__settings.getKey(self.__settingsSection,
 																	"{0}_viewSelecteIblSets".format(viewName)).toString())
 			LOGGER.debug("> '{0}' View stored selected Ibl Sets identities: '{1}'.".format(viewName,
 																							viewSelectedIblSetsIdentities))
@@ -1206,13 +1411,46 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 			view.storeModelSelection()
 			self.__settings.setKey(self.__settingsSection,
 								"{0}_viewSelecteIblSets".format(view.objectName()),
-								self.__settingsSeparator.join(foundations.strings.encode(identity) \
+								self.__settingsSeparator.join(foundations.strings.toString(identity) \
 								for identity in view.modelSelection["Default"]))
 
 		self.__settings.setKey(self.__settingsSection, "activeView", self.getActiveViewIndex())
 
 		return True
 
+	def __views_setUi(self, thumbnailsSize=None):
+		"""
+		This method sets the Views ui.
+
+		:param thumbnailsSize: Thumbnails size. ( Integer )
+		"""
+
+		if not thumbnailsSize:
+			thumbnailsSize = UiConstants.thumbnailsSizes.get(self.__panoramicThumbnailsSize \
+														if self.__panoramicThumbnails else self.__squareThumbnailsSize)
+		self.__iconPlaceHolder = \
+		sibl_gui.ui.common.getIcon(os.path.join(self.__uiResourcesDirectory,
+											self.__uiPanoramicLoadingImage if self.__panoramicThumbnails else \
+											self.__uiSquareLoadingImage),
+									asynchronousLoading=False)
+
+		self.__thumbnailsView._Thumbnails_QListView__setDefaultUiState(thumbnailsSize,
+																		2 if self.__panoramicThumbnails else 1)
+
+		self.Thumbnails_Size_horizontalSlider.setMinimum(UiConstants.thumbnailsSizes.get(self.__thumbnailsMinimumSize))
+		self.Thumbnails_Size_horizontalSlider.setMaximum(UiConstants.thumbnailsSizes.get(self.__panoramicThumbnailsSize \
+														if self.__panoramicThumbnails else self.__squareThumbnailsSize))
+		self.Thumbnails_Size_horizontalSlider.setValue(thumbnailsSize)
+
+	def __views_refreshUi(self, thumbnailsSize=None):
+		"""
+		This method refreshes the Views ui.
+
+		:param thumbnailsSize: Thumbnails size. ( Integer )
+		"""
+
+		self.__views_setUi(thumbnailsSize)
+
 	def __model__refreshNodes(self):
 		"""
 		This method is triggered when the Model Nodes need refresh.
@@ -1323,7 +1561,16 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 		self.Ibl_Sets_Outliner_Thumbnails_Slider_frame.setVisible(not index)
 		for viewIndex, data in self.__viewsPushButtons.iteritems():
 			viewPushButton, image = data
-			viewPushButton.setChecked(viewIndex == index and True or False)
+			viewPushButton.setChecked(True if viewIndex == index else False)
+
+	def __Switch_Thumbnails_Type_pushButton__clicked(self, checked):
+		"""
+		This method is triggered when **Switch_Thumbnails_Type_pushButton** Widget is clicked.
+
+		:param checked: Checked state. ( Boolean )
+		"""
+
+		self.setPanoramicThumbnails(not self.__panoramicThumbnails)
 
 	def __Search_Database_lineEdit__textChanged(self, text):
 		"""
@@ -1332,7 +1579,7 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 		:param text: Current text value. ( QString )
 		"""
 
-		self.setIblSets(self.__searchIblSets(foundations.strings.encode(self.Search_Database_lineEdit.text()),
+		self.setIblSets(self.__searchIblSets(foundations.strings.toString(self.Search_Database_lineEdit.text()),
 											self.__searchContexts[self.__activeSearchContext],
 											re.IGNORECASE if self.Case_Sensitive_Matching_pushButton.isChecked() else 0))
 
@@ -1343,9 +1590,7 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 		:param value: Thumbnails size. ( Integer )
 		"""
 
-		self.__thumbnailsView.listViewIconSize = value
-
-		self.__thumbnailsView._Thumbnails_QListView__setDefaultUiState()
+		self.__thumbnailsView._Thumbnails_QListView__setDefaultUiState(value, 2 if self.__panoramicThumbnails else 1)
 
 		# Storing settings key.
 		LOGGER.debug("> Setting '{0}' with value '{1}'.".format("listViewIconSize", value))
@@ -1368,10 +1613,11 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 
 		if not self.__engine.parameters.databaseReadOnly:
 			for url in event.mimeData().urls():
+				path = foundations.strings.toString(url.path())
+				LOGGER.debug("> Handling dropped '{0}' file.".format(path))
 				path = (platform.system() == "Windows" or platform.system() == "Microsoft") and \
-				re.search(r"^\/[A-Z]:", foundations.strings.encode(url.path())) and foundations.strings.encode(url.path())[1:] \
-				or foundations.strings.encode(url.path())
-				if re.search(r"\.{0}$".format(self.__extension), foundations.strings.encode(url.path())):
+				re.search(r"^\/[A-Z]:", path) and path[1:] or path
+				if re.search(r"\.{0}$".format(self.__extension), path):
 					name = foundations.strings.getSplitextBasename(path)
 					choice = messageBox.messageBox("Question", "Question",
 					"'{0}' Ibl Set file has been dropped, would you like to 'Add' it to the Database or \
@@ -1448,7 +1694,7 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 		self.__collectionsOutliner.getSelectedCollections() or \
 		self.__collectionsOutliner.getCollections())).intersection(
 		sibl_gui.components.core.database.operations.filterIblSets(
-		"{0}".format(foundations.strings.encode(pattern.pattern)), attribute, flags))]
+		"{0}".format(foundations.strings.toString(pattern.pattern)), attribute, flags))]
 		self.Search_Database_lineEdit.completer.setModel(QStringListModel(sorted((value
 														for value in set((getattr(iblSetNode, attribute)
 														for iblSetNode in iblSets if getattr(iblSetNode, attribute)))))))
@@ -1516,6 +1762,29 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 		self.Search_Database_lineEdit.setPlaceholderText(text)
 		return True
 
+	def setPanoramicThumbnails(self, state):
+		"""
+		This method sets the panoramic thumbnails.
+
+		:param state: Panoramic thumbnails. ( Boolean )
+		:return: Method succes. ( Boolean )
+		"""
+
+		oldIn, oldOut = UiConstants.thumbnailsSizes.get(self.__thumbnailsMinimumSize), UiConstants.thumbnailsSizes.get(
+					self.__panoramicThumbnailsSize if self.__panoramicThumbnails else self.__squareThumbnailsSize)
+
+		newIn, newOut = UiConstants.thumbnailsSizes.get(self.__thumbnailsMinimumSize), UiConstants.thumbnailsSizes.get(
+					self.__panoramicThumbnailsSize if state else self.__squareThumbnailsSize)
+
+		thumbnailsSize = (((self.Thumbnails_Size_horizontalSlider.value() - oldIn) * (newOut - newIn)) \
+						/ (oldOut - oldIn)) + newIn
+
+		self.__panoramicThumbnails = state
+		self.__settings.setKey(self.__settingsSection, "panoramicThumbnails", self.__panoramicThumbnails)
+		self.__views_refreshUi(thumbnailsSize)
+		self.setIblSets()
+		return True
+
 	@foundations.exceptions.handleExceptions(umbra.exceptions.notifyExceptionHandler, Exception)
 	@umbra.engine.showProcessing("Adding Content ...")
 	def addContentUi(self):
@@ -1785,7 +2054,7 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 
 		return list(set(self.getIblSets()).intersection(
 		sibl_gui.components.core.database.operations.filterIblSets(
-		"{0}".format(foundations.strings.encode(pattern.pattern)), attribute, flags)))
+		"{0}".format(foundations.strings.toString(pattern.pattern)), attribute, flags)))
 
 	def iblSetExists(self, path):
 		"""
@@ -1821,14 +2090,26 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 		iblSets = iblSets or self.__collectionsOutliner.getCollectionsIblSets(
 		self.__collectionsOutliner.getSelectedCollections() or self.__collectionsOutliner.getCollections())
 		rootNode = umbra.ui.nodes.DefaultNode(name="InvisibleRootNode")
+
 		for iblSet in iblSets:
+			if self.__panoramicThumbnails:
+				iconPath = foundations.common.getFirstItem(filter(foundations.common.pathExists, [iblSet.backgroundImage,
+																							iblSet.previewImage]))
+				iconSize = self.__panoramicThumbnailsSize
+			else:
+				iconPath = iblSet.icon
+				iconSize = self.__squareThumbnailsSize
+
 			iblSetNode = IblSetNode(iblSet,
 									name=iblSet.title,
 									parent=rootNode,
 									nodeFlags=nodeFlags,
-									attributesFlags=int(Qt.ItemIsSelectable | Qt.ItemIsEnabled))
+									attributesFlags=int(Qt.ItemIsSelectable | Qt.ItemIsEnabled),
+									iconPath=iconPath,
+									iconSize=iconSize,
+									iconPlaceholder=self.__iconPlaceHolder)
 
-			path = foundations.strings.encode(iblSet.path)
+			path = foundations.strings.toString(iblSet.path)
 			if not foundations.common.pathExists(path):
 				continue
 
