@@ -15,6 +15,11 @@
 
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
@@ -40,7 +45,7 @@ __maintainer__ = "Thomas Mansencal"
 __email__ = "thomas.mansencal@gmail.com"
 __status__ = "Production"
 
-__all__ = ["LOGGER", "Thumbnails_QListView", "Columns_QListView", "Details_QTreeView"]
+__all__ = ["LOGGER", "Thumbnails_QListView", "Details_QTreeView"]
 
 LOGGER = foundations.verbose.installLogger()
 
@@ -69,7 +74,6 @@ class Thumbnails_QListView(sibl_gui.ui.views.Abstract_QListView):
 		# --- Setting class attributes. ---
 		self.__listViewSpacing = 24
 		self.__listViewMargin = 32
-		self.__listViewIconSize = 128
 
 		Thumbnails_QListView.__initializeUi(self)
 
@@ -144,40 +148,6 @@ class Thumbnails_QListView(sibl_gui.ui.views.Abstract_QListView):
 		raise foundations.exceptions.ProgrammingError(
 		"{0} | '{1}' attribute is not deletable!".format(self.__class__.__name__, "listViewMargin"))
 
-	@property
-	def listViewIconSize(self):
-		"""
-		This method is the property for **self.__listViewIconSize** attribute.
-
-		:return: self.__listViewIconSize. ( Integer )
-		"""
-
-		return self.__listViewIconSize
-
-	@listViewIconSize.setter
-	@foundations.exceptions.handleExceptions(AssertionError)
-	def listViewIconSize(self, value):
-		"""
-		This method is the setter method for **self.__listViewIconSize** attribute.
-
-		:param value: Attribute value. ( Integer )
-		"""
-
-		if value is not None:
-			assert type(value) is int, "'{0}' attribute: '{1}' type is not 'int'!".format("listViewIconSize", value)
-			assert value > 0, "'{0}' attribute: '{1}' need to be exactly positive!".format("listViewIconSize", value)
-		self.__listViewIconSize = value
-
-	@listViewIconSize.deleter
-	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
-	def listViewIconSize(self):
-		"""
-		This method is the deleter method for **self.__listViewIconSize** attribute.
-		"""
-
-		raise foundations.exceptions.ProgrammingError(
-		"{0} | '{1}' attribute is not deletable!".format(self.__class__.__name__, "listViewIconSize"))
-
 	#******************************************************************************************************************
 	#***	Class methods.
 	#******************************************************************************************************************
@@ -198,62 +168,22 @@ class Thumbnails_QListView(sibl_gui.ui.views.Abstract_QListView):
 		# Signals / Slots.
 		self.model().modelReset.connect(self.__setDefaultUiState)
 
-	def __setDefaultUiState(self):
+	def __setDefaultUiState(self, iconsSize=None, iconsRatio=2):
 		"""
 		This method sets the Widget default ui state.
+
+		:param iconsSize: Icons size. ( Integer )
+		:param iconRatio: Icons ratio. ( Integer )
 		"""
 
 		LOGGER.debug("> Setting default View state!")
 
-		self.setIconSize(QSize(self.__listViewIconSize, self.__listViewIconSize))
-		self.setGridSize(QSize(self.__listViewIconSize + self.__listViewSpacing,
-								self.__listViewIconSize + self.__listViewMargin))
+		if not iconsSize:
+			return
 
-class Columns_QListView(sibl_gui.ui.views.Abstract_QListView):
-	"""
-	This class is used to display Database Ibl Sets in columns.
-	"""
-
-	def __init__(self, parent, model=None, readOnly=False, message=None):
-		"""
-		This method initializes the class.
-
-		:param parent: Object parent. ( QObject )
-		:param model: Model. ( QObject )
-		:param readOnly: View is read only. ( Boolean )
-		:param message: View default message when Model is empty. ( String )
-		"""
-
-		LOGGER.debug("> Initializing '{0}()' class.".format(self.__class__.__name__))
-
-		sibl_gui.ui.views.Abstract_QListView.__init__(self, parent, model, readOnly, message)
-
-		Columns_QListView.__initializeUi(self)
-
-	#******************************************************************************************************************
-	#***	Class methods.
-	#******************************************************************************************************************
-	def __initializeUi(self):
-		"""
-		This method initializes the Widget ui.
-		"""
-
-		self.setAutoScroll(True)
-		self.setResizeMode(QListView.Adjust)
-		self.setSelectionMode(QAbstractItemView.ExtendedSelection)
-		self.setDragDropMode(QAbstractItemView.DragOnly)
-
-		self.__setDefaultUiState()
-
-		# Signals / Slots.
-		self.model().modelReset.connect(self.__setDefaultUiState)
-
-	def __setDefaultUiState(self):
-		"""
-		This method sets the Widget default ui state.
-		"""
-
-		LOGGER.debug("> Setting default View state!")
+		self.setIconSize(QSize(iconsSize, iconsSize / iconsRatio))
+		self.setGridSize(QSize(iconsSize + self.__listViewSpacing, iconsSize / iconsRatio + self.__listViewMargin))
+		self.viewport().update()
 
 class Details_QTreeView(sibl_gui.ui.views.Abstract_QTreeView):
 	"""
