@@ -15,6 +15,11 @@
 
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
@@ -25,7 +30,7 @@ from PyQt4.QtCore import Qt
 #**********************************************************************************************************************
 import foundations.exceptions
 import foundations.verbose
-import umbra.ui.nodes
+import sibl_gui.ui.nodes
 
 #**********************************************************************************************************************
 #***	Module attributes.
@@ -44,7 +49,7 @@ LOGGER = foundations.verbose.installLogger()
 #**********************************************************************************************************************
 #***	Module classes and definitions.
 #**********************************************************************************************************************
-class PlatesNode(umbra.ui.nodes.GraphModelNode):
+class PlatesNode(sibl_gui.ui.nodes.GraphModelNode):
 	"""
 	This class factory defines :class:`sibl_gui.components.core.inspector.inspector.Inspector`
 		Component Interface class Model Plates node.
@@ -61,6 +66,8 @@ class PlatesNode(umbra.ui.nodes.GraphModelNode):
 				roles=None,
 				nodeFlags=int(Qt.ItemIsSelectable | Qt.ItemIsEnabled),
 				attributesFlags=int(Qt.ItemIsSelectable | Qt.ItemIsEnabled),
+				iconSize=None,
+				iconPlaceholder=None,
 				**kwargs):
 		"""
 		This method initializes the class.
@@ -72,12 +79,22 @@ class PlatesNode(umbra.ui.nodes.GraphModelNode):
 		:param roles: Roles. ( Dictionary )
 		:param nodeFlags: Node flags. ( Integer )
 		:param attributesFlags: Attributes flags. ( Integer )
+		:param iconSize: Icon size.  ( String )
+		:param iconPlaceholder: Icon placeholder.  ( QIcon )
 		:param \*\*kwargs: Keywords arguments. ( \*\* )
 		"""
 
 		LOGGER.debug("> Initializing '{0}()' class.".format(self.__class__.__name__))
 
-		umbra.ui.nodes.GraphModelNode.__init__(self, name, parent, children, roles, nodeFlags, **kwargs)
+		sibl_gui.ui.nodes.GraphModelNode.__init__(self,
+												name,
+												parent,
+												children,
+												roles,
+												nodeFlags,
+												iconSize,
+												iconPlaceholder,
+												**kwargs)
 
 		# --- Setting class attributes. ---
 		self.__plate = plate
