@@ -14,6 +14,11 @@
 
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
@@ -979,7 +984,7 @@ class TemplatesOutliner(QWidgetComponentFactory(uiFile=COMPONENT_UI_FILE)):
 			LOGGER.info("{0} | Database default Templates wizard and Templates integrity checking method deactivated\
 by '{1}' command line parameter value!".format(self.__class__.__name__, "databaseReadOnly"))
 
-		activeCollectionsIdentities = foundations.strings.encode(self.__settings.getKey(
+		activeCollectionsIdentities = foundations.strings.toString(self.__settings.getKey(
 		self.__settingsSection, "activeCollections").toString())
 		LOGGER.debug("> Stored '{0}' active Collections selection: '{1}'.".format(self.__class__.__name__,
 																				activeCollectionsIdentities))
@@ -987,12 +992,12 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 																		for identity in activeCollectionsIdentities.split(
 																		self.__settingsSeparator)] or []
 
-		activeSoftwares = foundations.strings.encode(
+		activeSoftwares = foundations.strings.toString(
 		self.__settings.getKey(self.__settingsSection, "activeSoftwares").toString())
 		LOGGER.debug("> Stored '{0}' active softwares selection: '{1}'.".format(self.__class__.__name__, activeSoftwares))
 		self.__view.modelSelection["Softwares"] = activeSoftwares and activeSoftwares.split(self.__settingsSeparator) or []
 
-		activeTemplatesIdentities = foundations.strings.encode(
+		activeTemplatesIdentities = foundations.strings.toString(
 		self.__settings.getKey(self.__settingsSection, "activeTemplates").toString())
 		LOGGER.debug("> '{0}' View stored selected Templates identities '{1}'.".format(self.__class__.__name__,
 																						activeTemplatesIdentities))
@@ -1015,15 +1020,15 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 		self.__view.storeModelSelection()
 		self.__settings.setKey(self.__settingsSection,
 								"activeTemplates",
-								self.__settingsSeparator.join(foundations.strings.encode(identity)
+								self.__settingsSeparator.join(foundations.strings.toString(identity)
 															for identity in self.__view.modelSelection["Templates"]))
 		self.__settings.setKey(self.__settingsSection,
 								"activeCollections",
-								self.__settingsSeparator.join(foundations.strings.encode(identity)
+								self.__settingsSeparator.join(foundations.strings.toString(identity)
 															for identity in self.__view.modelSelection["Collections"]))
 		self.__settings.setKey(self.__settingsSection,
 								"activeSoftwares",
-								self.__settingsSeparator.join(foundations.strings.encode(name)
+								self.__settingsSeparator.join(foundations.strings.toString(name)
 															for name in self.__view.modelSelection["Softwares"]))
 		return True
 
@@ -1150,7 +1155,7 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 		else:
 			content.append(self.__templatesInformationsDefaultText)
 
-		separator = str() if len(content) == 1 else "<p><center>* * *<center/></p>"
+		separator = "" if len(content) == 1 else "<p><center>* * *<center/></p>"
 
 		self.Template_Informations_textBrowser.setText(separator.join(content))
 
@@ -1171,10 +1176,11 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 
 		if not self.__engine.parameters.databaseReadOnly:
 			for url in event.mimeData().urls():
+				path = foundations.strings.toString(url.path())
+				LOGGER.debug("> Handling dropped '{0}' file.".format(path))
 				path = (platform.system() == "Windows" or platform.system() == "Microsoft") and \
-				re.search(r"^\/[A-Z]:", foundations.strings.encode(url.path())) and foundations.strings.encode(url.path())[1:] or \
-				foundations.strings.encode(url.path())
-				if re.search(r"\.{0}$".format(self.__extension), foundations.strings.encode(url.path())):
+				re.search(r"^\/[A-Z]:", path) and path[1:] or path
+				if re.search(r"\.{0}$".format(self.__extension), path):
 					name = foundations.strings.getSplitextBasename(path)
 					choice = messageBox.messageBox("Question", "Question",
 					"'{0}' Template file has been dropped, would you like to 'Add' it to the Database or \
@@ -1305,7 +1311,7 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 
 		if messageBox.messageBox("Question", "Question",
 		"Are you sure you want to remove '{0}' Template(s)?".format(
-		", ".join([foundations.strings.encode(template.name) for template in selectedTemplates])),
+		", ".join([foundations.strings.toString(template.name) for template in selectedTemplates])),
 		buttons=QMessageBox.Yes | QMessageBox.No) == QMessageBox.Yes:
 			self.__engine.startProcessing("Removing Templates ...", len(selectedTemplates))
 			success = True
@@ -1527,7 +1533,7 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 		"""
 
 		LOGGER.info("{0} | Removing '{1}' Template from the Database!".format(self.__class__.__name__, template.name))
-		if sibl_gui.components.core.database.operations.removeTemplate(foundations.strings.encode(template.id)):
+		if sibl_gui.components.core.database.operations.removeTemplate(foundations.strings.toString(template.id)):
 			self.refreshNodes.emit()
 			return True
 		else:
@@ -1592,7 +1598,7 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 			return list()
 
 		return sibl_gui.components.core.database.operations.filterTemplatesCollections(
-		"{0}".format(foundations.strings.encode(pattern.pattern)), attribute, flags)
+		"{0}".format(foundations.strings.toString(pattern.pattern)), attribute, flags)
 
 	def getTemplates(self):
 		"""
@@ -1621,7 +1627,7 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 
 		return list(set(self.getTemplates()).intersection(
 		sibl_gui.components.core.database.operations.filterTemplates(
-		"{0}".format(foundations.strings.encode(pattern.pattern)), attribute, flags)))
+		"{0}".format(foundations.strings.toString(pattern.pattern)), attribute, flags)))
 
 	def listTemplates(self):
 		"""
@@ -1654,7 +1660,10 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 											parent=rootNode,
 											nodeFlags=int(Qt.ItemIsSelectable | Qt.ItemIsEnabled),
 											attributesFlags=int(Qt.ItemIsSelectable | Qt.ItemIsEnabled))
-
+			collectionNode["release"] = sibl_gui.ui.nodes.GraphModelAttribute(name="release",
+																flags=int(Qt.ItemIsSelectable | Qt.ItemIsEnabled))
+			collectionNode["version"] = sibl_gui.ui.nodes.GraphModelAttribute(name="version",
+																flags=int(Qt.ItemIsSelectable | Qt.ItemIsEnabled))
 			for software in softwares:
 				templates = set((template for template in sibl_gui.components.core.database.operations.query(
 							Template).filter(Template.collection == collection.id).filter(
@@ -1668,7 +1677,7 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 											nodeFlags=int(Qt.ItemIsSelectable | Qt.ItemIsEnabled),
 											attributesFlags=int(Qt.ItemIsSelectable | Qt.ItemIsEnabled))
 				iconPath = os.path.join(self.__uiResourcesDirectory, "{0}{1}".format(software, self.__uiSoftwareAffixe))
-				softwareNode.roles[Qt.DecorationRole] = foundations.common.pathExists(iconPath) and iconPath or \
+				softwareNode.roles[Qt.DecorationRole] = iconPath if foundations.common.pathExists(iconPath) else \
 												os.path.join(self.__uiResourcesDirectory, self.__uiUnknownSoftwareImage)
 
 				for template in templates:
@@ -1678,7 +1687,7 @@ by '{1}' command line parameter value!".format(self.__class__.__name__, "databas
 												nodeFlags=nodeFlags,
 												attributesFlags=attributesFlags)
 
-					path = foundations.strings.encode(template.path)
+					path = foundations.strings.toString(template.path)
 					if not foundations.common.pathExists(path):
 						continue
 
