@@ -14,6 +14,11 @@
 
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
@@ -46,10 +51,10 @@ class Constants():
 	"""Package major version: '**4**' ( String )"""
 	minorVersion = "0"
 	"""Package minor version: '**0**' ( String )"""
-	changeVersion = "6"
-	"""Package change version: '**6**' ( String )"""
+	changeVersion = "7"
+	"""Package change version: '**7**' ( String )"""
 	releaseVersion = ".".join((majorVersion, minorVersion, changeVersion))
-	"""Package release version: '**4.0.6**' ( String )"""
+	"""Package release version: '**4.0.7**' ( String )"""
 
 	logger = "sIBL_GUI_Logger"
 	"""Package logger name: '**sIBL_GUI_Logger**' ( String )"""
@@ -65,12 +70,6 @@ class Constants():
 
 	databaseDirectory = "database"
 	"""Application Database directory: '**database**' ( String )"""
-	databaseMigrationsDirectory = "migrations"
-	"""Application Database migrations directory: '**migrations**' ( String )"""
-	databaseMigrationsFilesDirectory = "versions"
-	"""Application Database migrations files versions directory: '**versions**' ( String )"""
-	databaseMigrationsTemplatesDirectory = "templates"
-	"""Application Database migrations templates files directory: '**templates**' ( String )"""
 	patchesDirectory = "patches"
 	"""Application patches directory: '**patches**' ( String )"""
 	settingsDirectory = "settings"
@@ -84,7 +83,6 @@ class Constants():
 	ioDirectory = "io"
 	"""Application io directory: '**io**' ( String )"""
 
-
 	preferencesDirectories = (databaseDirectory,
 								patchesDirectory,
 								settingsDirectory,
