@@ -14,6 +14,11 @@
 
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
 #**********************************************************************************************************************
 #***	Module attributes.
 #**********************************************************************************************************************
@@ -39,5 +44,9 @@ class RuntimeGlobals():
 	templatesUserDirectory = None
 	"""Templates user directory."""
 
+	thumbnailsCacheDirectory = None
+	"""Thumbnails cache directory."""
+
 	imagesCaches = None
 	"""Images cache."""
+
