@@ -14,6 +14,11 @@
 
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
 #**********************************************************************************************************************
 #***	Module attributes.
 #**********************************************************************************************************************
@@ -145,19 +150,31 @@ class UiConstants():
 	"""Application online donation file:
 	'**http://kelsolaar.hdrlabs.com/sIBL_GUI/Support/Donations/Make_A_Donation.html**' ( String )"""
 
-	nativeImageFormats = { "Bmp" : "\.bmp$",
-							"Jpeg" : "\.jpeg$",
-							"Jpg" : "\.jpg$",
-							"Png" : "\.png$" }
+	nativeImageFormats = {"Bmp" : "\.bmp$",
+						"Jpeg" : "\.jpeg$",
+						"Jpg" : "\.jpg$",
+						"Png" : "\.png$" }
 	"""Application native image file formats. ( Dictionary )"""
 
-	thirdPartyImageFormats = { "Exr" : ("\.exr$"),
-								"Hdr" : ("\.hdr$"),
-								"Tif" : ("\.tif$"),
-								"Tiff" : ("\.tiff$"),
-								"Tga" : ("\.tga$")}
+	thirdPartyImageFormats = {"Exr" : ("\.exr$"),
+							"Hdr" : ("\.hdr$"),
+							"Tif" : ("\.tif$"),
+							"Tiff" : ("\.tiff$"),
+							"Tga" : ("\.tga$")}
 	"""Application third party image file formats. ( Dictionary )"""
 
-	crittercismId = "50aa8ac9866b845bd6000007"
-	"""Crittercism Id: '**50aa8ac9866b845bd6000007**' ( String )"""
+	thumbnailsSizes = { "Default" : None,
+					"XLarge" : 512,
+					"Large" : 256,
+					"Medium" : 128,
+					"Small" : 64,
+					"XSmall" : 32,
+					"Special1" : 600}
+	"""Application thumbnails sizes. ( Dictionary )"""
+
+	thumbnailsCacheDirectory = "thumbnails"
+	"""Thumbnails cache directory."""
+
+	crittercismId = "51290b3589ea7429250004fe"
+	"""Crittercism Id: '**51290b3589ea7429250004fe**' ( String )"""
 
