@@ -15,6 +15,11 @@
 	Michele Petrazzo: http://freeimagepy.sourceforge.net/ and ctypesgen: http://code.google.com/p/ctypesgen/.
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
@@ -1189,8 +1194,8 @@ FREEIMAGE_FUNCTIONS = (
 				argumentsTypes=[FreeImage_OutputMessageFunction],
 				returnValue=None),
 	# LibraryHook(name="FreeImage_OutputMessageProc",
-	#			argumentstype=none, 
-	#			returnValue=none),
+	# 			argumentstype=none,
+	# 			returnValue=none),
 	# FreeImage_OutputMessageProc is a variadic function and is not supported by ctypes.
 
 	# Allocate / clone / unload functions.
@@ -1278,8 +1283,8 @@ FREEIMAGE_FUNCTIONS = (
 				argumentsTypes=[FI_InitProc, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_char_p],
 				returnValue=FREE_IMAGE_FORMAT),
 	# LibraryHook(name="FreeImage_RegisterExternalPlugin",
-	#			argumentstype=[ctypes.c_char_p, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_char_p], 
-	#			returnValue=FREE_IMAGE_FORMAT),
+	# 			argumentstype=[ctypes.c_char_p, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_char_p],
+	# 			returnValue=FREE_IMAGE_FORMAT),
 	LibraryHook(name="FreeImage_GetFIFCount",
 				argumentsTypes=[],
 				returnValue=ctypes.c_int),
@@ -2140,8 +2145,7 @@ class Image(object):
 		"""
 
 		if value is not None:
-			assert type(value) in (str, unicode), \
-			"'{0}' attribute: '{1}' type is not 'str', 'unicode'!".format("imagePath", value)
+			assert type(value) is unicode, "'{0}' attribute: '{1}' type is not 'unicode'!".format("imagePath", value)
 		self.__imagePath = value
 
 	@imagePath.deleter
@@ -2215,11 +2219,10 @@ class Image(object):
 		return fileFormat
 
 	@foundations.exceptions.handleExceptions(foundations.exceptions.LibraryExecutionError)
-	def load(self, imagePath=None):
+	def load(self):
 		"""
 		This method loads the file.
 
-		:param imagePath: Image path. ( String )
 		:return: Method success. ( Boolean )
 		"""
 
