@@ -14,6 +14,11 @@
 
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
@@ -55,6 +60,7 @@ class RuntimeGlobalsTestCase(unittest.TestCase):
 
 		requiredAttributes = ("templatesFactoryDirectory",
 								"templatesUserDirectory",
+								"thumbnailsCacheDirectory",
 								"imagesCaches")
 
 		for attribute in requiredAttributes:
