@@ -14,12 +14,19 @@
 
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
+import hashlib
 import itertools
 import os
 import re
+from PyQt4.QtCore import Qt
 from PyQt4.QtGui import QColor
 from PyQt4.QtGui import QIcon
 from PyQt4.QtGui import QImage
@@ -37,7 +44,7 @@ import sibl_gui.exceptions
 import umbra.ui.common
 from sibl_gui.libraries.freeImage.freeImage import Image
 from sibl_gui.libraries.freeImage.freeImage import ImageInformationsHeader
-from sibl_gui.globals.uiConstants import UiConstants
+from umbra.globals.uiConstants import UiConstants
 from umbra.globals.constants import Constants
 from umbra.globals.runtimeGlobals import RuntimeGlobals
 
@@ -52,16 +59,18 @@ __email__ = "thomas.mansencal@gmail.com"
 __status__ = "Production"
 
 __all__ = ["LOGGER",
-			"convertImage",
-			"loadGraphicsItem",
-			"getGraphicsItem",
-			"getIcon",
-			"getPixmap",
-			"getImage",
-			"createPixmap",
-			"getImageInformationsHeader",
-			"filterImagePath",
-			"getFormatedShotDate"]
+		"convertImage",
+		"getThumbnailPath",
+		"extractThumbnail",
+		"loadGraphicsItem",
+		"getGraphicsItem",
+		"getIcon",
+		"getPixmap",
+		"getImage",
+		"createPixmap",
+		"getImageInformationsHeader",
+		"filterImagePath",
+		"getFormatedShotDate"]
 
 LOGGER = foundations.verbose.installLogger()
 
@@ -70,9 +79,10 @@ LOGGER = foundations.verbose.installLogger()
 #**********************************************************************************************************************
 def convertImage(image, type):
 	"""
-	This method converts given image to given type.
+	This definition converts given image to given type.
 
 	:param image: Image to convert. ( QImage )
+	:param type: Type to convert to. ( QImage / QPixmap / QIcon )
 	:return: Converted image. ( QImage / QPixmap / QIcon )
 	"""
 
@@ -84,14 +94,64 @@ def convertImage(image, type):
 
 	return graphicsItem
 
-def loadGraphicsItem(path, type):
+def getThumbnailPath(path, size, cacheDirectory=None):
 	"""
-	This method loads a graphic item: `QIcon <http://doc.qt.nokia.com/qicon.html>`_,
+	This definition returns given image thumbnail cached path at given size.
+
+	:param path: Image path. ( String )
+	:param size: Thumbnail size. ( String )
+	:param cacheDirectory: Thumbnails cache directory. ( String )
+	:return: Cached thumbnail path. ( String )
+	"""
+
+	cacheDirectory = cacheDirectory if cacheDirectory is not None else RuntimeGlobals.thumbnailsCacheDirectory
+	return os.path.join(cacheDirectory,
+					hashlib.md5("{0}_{1}.png".format(path, size).encode(Constants.encodingCodec)).hexdigest())
+
+def extractThumbnail(path,
+					size="Default",
+					image=None,
+					format="PNG",
+					quality= -1,
+					cacheDirectory=None):
+	"""
+	This definition extract given image thumbnail at given size.
+
+	:param path: Image path. ( String )
+	:param size: Thumbnail size. ( String )
+	:param image: Image to use instead of given path one. ( QImage )
+	:param format: Thumbnail format. ( String )
+	:param quality: Thumbnail quality, -1 to 100. ( Integer )
+	:param cacheDirectory: Thumbnails cache directory. ( String )
+	:return: Thumbnail image. ( QImage )
+	"""
+
+	cacheDirectory = cacheDirectory if cacheDirectory is not None else RuntimeGlobals.thumbnailsCacheDirectory
+
+	if not foundations.common.pathExists(cacheDirectory):
+		foundations.io.setDirectory(cacheDirectory)
+
+	thumbnailPath = getThumbnailPath(path, size, cacheDirectory)
+	if not os.path.exists(thumbnailPath):
+		thumbnail = QImage(path) if image is None else image
+		thumbnail = thumbnail.scaled(UiConstants.thumbnailsSizes.get(size),
+							UiConstants.thumbnailsSizes.get(size),
+							Qt.KeepAspectRatio,
+							Qt.SmoothTransformation)
+		thumbnail.save(thumbnailPath, format, quality)
+		return thumbnail
+	else:
+		return QImage(thumbnailPath)
+
+def loadGraphicsItem(path, type, size="Default"):
+	"""
+	This definition loads a graphic item: `QIcon <http://doc.qt.nokia.com/qicon.html>`_,
 	`QImage <http://doc.qt.nokia.com/qimage.html>`_, `QPixmap <http://doc.qt.nokia.com/qpixmap.html>`_.
 
 	:param path: Image path. ( String )
 	:param type: QIcon, QImage, QPixmap. ( QObject )
-	:return: Graphics item. ( QIcon, QImage, QPixmap )
+	:param size: Image size. ( String )
+	:return: Image. ( QIcon, QImage, QPixmap )
 	"""
 
 	if not foundations.common.pathExists(path):
@@ -99,7 +159,7 @@ def loadGraphicsItem(path, type):
 	else:
 		for extension in UiConstants.nativeImageFormats.itervalues():
 			if re.search(extension, path, flags=re.IGNORECASE):
-				graphicsItem = type(path)
+				graphicsItem = convertImage(extractThumbnail(path, size), type) if size != "Default" else type(path)
 				break
 		else:
 			errorImage = umbra.ui.common.getResourcePath(UiConstants.formatErrorImage)
@@ -108,86 +168,99 @@ def loadGraphicsItem(path, type):
 					try:
 						image = Image(path)
 						image = image.convertToQImage()
-						graphicsItem = convertImage(image, type)
+						graphicsItem = \
+						convertImage(extractThumbnail(path, size, image), type) if size != "Default" else \
+						convertImage(image, type)
 						break
 					except Exception as error:
 						LOGGER.error("!> {0} | Exception raised while reading '{1}' image: '{2}'!".format(__name__,
-																										path,
-																										error))
+																									path,
+																									error))
 						graphicsItem = type(errorImage)
 						break
 			else:
 				graphicsItem = type(errorImage)
 	return graphicsItem
 
-def getGraphicsItem(path, type, asynchronousLoading=True, imagesCache=None):
+def getGraphicsItem(path, type, size="Default", asynchronousLoading=True, placeholder=None, imagesCache=None):
 	"""
-	This method returns a display item: `QIcon <http://doc.qt.nokia.com/qicon.html>`_,
+	This definition returns a display item: `QIcon <http://doc.qt.nokia.com/qicon.html>`_,
 	`QImage <http://doc.qt.nokia.com/qimage.html>`_, `QPixmap <http://doc.qt.nokia.com/qpixmap.html>`_ instance.
 
 	:param path: Image path. ( String )
 	:param type: QIcon, QImage, QPixmap. ( QObject )
+	:param size: Image size. ( String )
 	:param asynchronousLoading: Images are loaded asynchronously. ( Boolean )
+	:param placeholder: Placeholder to use while loading asynchronously. ( QIcon, QImage, QPixmap )
 	:param imagesCache: Image cache. ( Dictionary / AsynchronousGraphicsItemsCache )
-	:return: Graphic display. ( QIcon, QImage, QPixmap )
+	:return: Image. ( QIcon, QImage, QPixmap )
 	"""
 
 	if not foundations.common.pathExists(path):
 		LOGGER.warning("!> {0} | '{1}' file doesn't exists!".format(__name__, path))
-		return loadGraphicsItem(path, type)
+		return loadGraphicsItem(path, type, size)
 
 	cache = imagesCache and imagesCache or RuntimeGlobals.imagesCaches.get(type.__name__)
 	if cache is None:
 		raise sibl_gui.exceptions.CacheExistsError("{0} | '{1}' cache doesn't exists!".format(__name__, type.__name__))
 
-	if asynchronousLoading:
-		cache.addDeferredContent(path)
-	else:
-		not cache.getContent(path) and cache.addContent(**{str(path) : loadGraphicsItem(path, type)})
-	return cache.getContent(path)
+	graphicsItem = cache.getContent(path, size)
+	if graphicsItem is None:
+		if asynchronousLoading:
+			cache.loadAsynchronousContent(**{path : (type, size, placeholder)})
+		else:
+			cache.loadContent(**{path : (type, size)})
+		return cache.getContent(path, size)
+	return graphicsItem
 
-def getIcon(path, asynchronousLoading=True, imagesCache=None):
+def getIcon(path, size="Default", asynchronousLoading=True, placeholder=None, imagesCache=None):
 	"""
-	This method returns a `QIcon <http://doc.qt.nokia.com/qicon.html>`_ instance.
+	This definition returns a `QIcon <http://doc.qt.nokia.com/qicon.html>`_ instance.
 
 	:param path: Icon image path. ( String )
+	:param size: Image size. ( String )
 	:param asynchronousLoading: Images are loaded asynchronously. ( Boolean )
+	:param placeholder: Placeholder to use while loading asynchronously. ( QIcon )
 	:param imagesCache: Image cache. ( Dictionary / AsynchronousGraphicsItemsCache )
 	:return: QIcon. ( QIcon )
 	"""
 
 	cache = imagesCache and imagesCache or RuntimeGlobals.imagesCaches.get("QIcon")
-	return getGraphicsItem(path, QIcon, asynchronousLoading, cache)
+	return getGraphicsItem(path, QIcon, size, asynchronousLoading, placeholder, cache)
 
-def getPixmap(path, asynchronousLoading=True, imagesCache=None):
+def getPixmap(path, size="Default", asynchronousLoading=True, placeholder=None, imagesCache=None):
 	"""
-	This method returns a `QPixmap <http://doc.qt.nokia.com/qpixmap.html>`_ instance.
+	This definition returns a `QPixmap <http://doc.qt.nokia.com/qpixmap.html>`_ instance.
 
 	:param path: Icon image path. ( String )
+	:param size: Image size. ( String )
 	:param asynchronousLoading: Images are loaded asynchronously. ( Boolean )
+	:param placeholder: Placeholder to use while loading asynchronously. ( QPixmap )
 	:param imagesCache: Image cache. ( Dictionary / AsynchronousGraphicsItemsCache )
 	:return: QPixmap. ( QPixmap )
 	"""
 
 	cache = imagesCache and imagesCache or RuntimeGlobals.imagesCaches.get("QPixmap")
-	return getGraphicsItem(path, QPixmap, asynchronousLoading, cache)
+	return getGraphicsItem(path, QPixmap, size, asynchronousLoading, placeholder, cache)
 
-def getImage(path, asynchronousLoading=True, imagesCache=None):
+def getImage(path, size="Default", asynchronousLoading=True, placeholder=None, imagesCache=None):
 	"""
-	This method returns a `QImage <http://doc.qt.nokia.com/qimage.html>`_ instance.
+	This definition returns a `QImage <http://doc.qt.nokia.com/qimage.html>`_ instance.
 
 	:param path: Icon image path. ( String )
+	:param size: Image size. ( String )
 	:param asynchronousLoading: Images are loaded asynchronously. ( Boolean )
+	:param placeholder: Placeholder to use while loading asynchronously. ( QImage )
 	:param imagesCache: Image cache. ( Dictionary / AsynchronousGraphicsItemsCache )
 	:return: QImage. ( QImage )
 	"""
 
 	cache = imagesCache and imagesCache or RuntimeGlobals.imagesCaches.get("QImage")
-	return getGraphicsItem(path, QImage, asynchronousLoading, cache)
+	return getGraphicsItem(path, QImage, size, asynchronousLoading, placeholder, cache)
 
 def createPixmap(width=128, height=128, text=None):
 	"""
-	This method create a default `QPixmap <http://doc.qt.nokia.com/qpixmap.html>`_ instance.
+	This definition create a default `QPixmap <http://doc.qt.nokia.com/qpixmap.html>`_ instance.
 
 	:param width: Pixmap width. ( Integer )
 	:param height: Pixmap height. ( Integer )
@@ -208,7 +281,7 @@ def createPixmap(width=128, height=128, text=None):
 @foundations.exceptions.handleExceptions(foundations.exceptions.FileExistsError)
 def getImageInformationsHeader(path, graphicsItem):
 	"""
-	This method returns a :class:`sibl_gui.libraries.freeImage.freeImage.ImageInformationsHeader` class
+	This definition returns a :class:`sibl_gui.libraries.freeImage.freeImage.ImageInformationsHeader` class
 	from given path and graphics item.
 
 	:param path: Image path. ( String )
@@ -230,7 +303,7 @@ def getImageInformationsHeader(path, graphicsItem):
 
 def filterImagePath(path):
 	"""
-	This method filters the image path.
+	This definition filters the image path.
 
 	:param path: Image path. ( String )
 	:return: Path. ( String )
@@ -248,7 +321,7 @@ def filterImagePath(path):
 
 def getFormatedShotDate(date, time):
 	"""
-	This method returns a formated shot date.
+	This definition returns a formated shot date.
 
 	:param date: Ibl Set date key value. ( String )
 	:param time: Ibl Set time key value. ( String )
