@@ -14,11 +14,30 @@
 
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
+#**********************************************************************************************************************
+#***	Encoding manipulations.
+#**********************************************************************************************************************
+import sys
+
+def _setEncoding():
+	"""
+	This definition sets the Application encoding.
+	"""
+
+	reload(sys)
+	sys.setdefaultencoding("utf-8")
+
+_setEncoding()
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
 import os
-import sys
 
 #**********************************************************************************************************************
 #***	Module attributes.
@@ -49,7 +68,7 @@ def recursiveRemove(rootDirectory, pattern):
 	for root, dirs, files in os.walk(rootDirectory, followlinks=True):
 		for item in files:
 			itemPath = os.path.join(root, item).replace("\\", "/")
-			if pattern in unicode(item):
+			if pattern in item:
 				remove(itemPath)
 
 def remove(item):
@@ -65,4 +84,5 @@ def remove(item):
 		print("{0} | '{1}' file removing failed!".format(remove.__name__, item))
 
 if __name__ == "__main__":
-	recursiveRemove(sys.argv[1], sys.argv[2])
+	arguments = map(unicode, sys.argv)
+	recursiveRemove(arguments[1], arguments[2])
